@@ -6,21 +6,25 @@ import seaborn as sns
 
 class Univariate:
     """
+    The univariate statistical analysis class is designed to create a wide range of visualisations and metrics that can
+    be used to develop an understanding of the underlying structure of a single data variable. This analysis can be
+    useful as part of a wider analysis. Specifically this analysis is designed to determine if a variable has the
+    required underlying structure to be used in further analysis. For example this analysis can be used to determine
+    if a variable is suitable for linear regression via analysis of its distribution.
 
-    Useful Resources:
+    Usage:
+    from argali import descriptive_statistics
+    x = [1, 2, 3, 4, 3, 4, 5, 6, 7, 6, 7, 8, 7, 8, 8, 6, 5, 44, 3, 4, 5, 6, 7, 8, 9, 33, 22, 11, -1]
+    x_summary = descriptive_statistics.Univariate(data=x)
+    x_summary.descriptive_summary()
+
+    For additional understanding and explanations around univariate analysis see the following useful resources:
     https://www.arpm.co/symmys-articles/Risk%20and%20Asset%20Allocation%20-%20Springer%20Quantitative%20Finance%20-%20Statistics.pdf
     https://learn.stleonards.vic.edu.au/vcefurthermaths/files/2012/07/Univariate-Statistics-Summary.pdf
     https://psych.unl.edu/psycrs/350/unit2/univ.pdf
     https://www3.nd.edu/~rwilliam/stats1/x03.pdf
     https://www.andrews.edu/~calkins/math/webtexts/statall.pdf
 
-    Usage:
-
-    from argali import descriptive_statistics
-    x = [1, 2, 3, 4, 3, 4, 5, 6, 7, 6, 7, 8, 7, 8, 8, 6, 5, 44, 3, 4, 5, 6, 7, 8, 9, 33, 22, 11, -1]
-    x_summary = descriptive_statistics.Univariate(data=x)
-    x_summary.descriptive_summary()
-
     """
 
     def __init__(self, data):
@@ -35,6 +39,10 @@ class Univariate:
         return mean
 
     def geometric_mean(self):
+        """
+        calculates the geometric mean of a single variable
+        :return: geometric mean
+        """
         product = 1
         for x in self.data:
             product = product * x
@@ -44,6 +52,10 @@ class Univariate:
         return geometric_mean
 
     def harmonic_mean(self):
+        """
+        calculates the harmonic mean of a single variable
+        :return: geometric mean
+        """
         reciprocal = []
         for i in self.data:
             reciprocal.append(i ** -1)
@@ -52,6 +64,10 @@ class Univariate:
         return harmonic_mean
 
     def quadratic_mean(self):
+        """
+        calculates the quadratic mean of a single variable
+        :return: quadratic mean
+        """
         squared = []
         for i in self.data:
             squared.append(i ** 2)
@@ -59,6 +75,10 @@ class Univariate:
         return quadratic_mean
 
     def trimmed_mean_01(self):
+        """
+        calculates the trimmed mean of a single variable removing the largest and smallest value
+        :return: trimmed mean
+        """
 
         trim_index = round(len(self.data) / 100)
 
@@ -71,6 +91,10 @@ class Univariate:
         return trimmed_mean
 
     def trimmed_mean_05(self):
+        """
+        calculates the trimmed mean of a single variable removing the largest and smallest 5% of values
+        :return: trimmed mean
+        """
 
         trim_index = round(len(self.data) / 100) * 5
 
@@ -83,6 +107,10 @@ class Univariate:
         return trimmed_mean
 
     def trimmed_mean_10(self):
+        """
+        calculates the trimmed mean of a single variable removing the largest and smallest 10% of values
+        :return: trimmed mean
+        """
 
         trim_index = round(len(self.data) / 100) * 10
 
@@ -95,7 +123,14 @@ class Univariate:
         return trimmed_mean
 
     def trimmed_mean_custom(self, trim_percentage):
+        """
+        calculates the trimmed mean of a single variable removing the largest and smallest 5% of values, make sure to
+        include the percentage of trim that is desirable for your analysis. This is not included in the statistical
+        summary function and needs to be called on its own.
 
+        :param trim_percentage: int or float value, 10 or 10.0 = 10%
+        :return: trimmed mean
+        """
         trim_index = round(len(self.data) / 100) * trim_percentage
 
         if trim_index == 0:
@@ -107,6 +142,10 @@ class Univariate:
         return trimmed_mean
 
     def median(self):
+        """
+        calculates the median of a single variable
+        :return: median
+        """
         sorted_ = sorted(self.data)
         if len(sorted_) % 2 == 0:
             median_index = (len(sorted_) / 2) - 1
@@ -119,6 +158,10 @@ class Univariate:
         return median
 
     def percentile_30(self):
+        """
+        calculates the value at the 30th percentile when all values have been ordered from smallest to largest.
+        :return: 30th percentile
+        """
         rank = round(30 / 100 * (len(sorted(self.data))))
         rank += 1
         sorted_ = sorted(self.data)
@@ -126,6 +169,10 @@ class Univariate:
         return rank
 
     def percentile_70(self):
+        """
+        calculates the value at the 70th percentile when all values have been ordered from smallest to largest.
+        :return: 70th percentile
+        """
         rank = round(70 / 100 * (len(sorted(self.data))))
         rank += 1
         sorted_ = sorted(self.data)
@@ -134,10 +181,19 @@ class Univariate:
         return rank
 
     def interquartile_range(self):
+        """
+        calculates the difference between the 30th and 70th percentile when all values have been ordered from smallest
+        to largest.
+        :return: IQR.
+        """
         iqr = self.percentile_70() - self.percentile_30()
         return iqr
 
     def unique_value_list(self):
+        """
+        returns a list of all the unique values in a single variable.
+        :return: unique value list
+        """
         unique_values = []
         for i in sorted(self.data):
             if i not in unique_values:
@@ -146,6 +202,10 @@ class Univariate:
         return unique_values
 
     def unique_value_count(self):
+        """
+        returns the count of unique values in a list.
+        :return: unique value count as an int
+        """
         return len(self.unique_value_list())
 
     def unique_value_frequency(self):
